@@ -1,16 +1,17 @@
 package Business::ID::NOPPBB;
 
-our $DATE = '2019-11-21'; # DATE
-our $DIST = 'Business-ID-NOPPBB'; # DIST
-our $VERSION = '0.090'; # VERSION
-
 use 5.010001;
 use warnings;
 use strict;
 
-use Locale::ID::Province qw(list_id_provinces);
-
 use Exporter 'import';
+use Locale::ID::Province qw(list_idn_provinces);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-10-04'; # DATE
+our $DIST = 'Business-ID-NOPPBB'; # DIST
+our $VERSION = '0.091'; # VERSION
+
 our @EXPORT_OK = qw(validate_nop_pbb);
 
 our %SPEC;
@@ -67,7 +68,7 @@ sub validate_nop_pbb {
     # cache provinces, key is code
     state $provs;
     if (!$provs) {
-        my $res = list_id_provinces(
+        my $res = list_idn_provinces(
             fields=>['bps_code', 'ind_name', 'eng_name'],
             with_field_names => 1);
         $res->[0] == 200 or die "Can't retrieve list of provinces: ".
@@ -111,7 +112,7 @@ Business::ID::NOPPBB - Validate (and parse) Indonesian property tax number (NOP
 
 =head1 VERSION
 
-This document describes version 0.090 of Business::ID::NOPPBB (from Perl distribution Business-ID-NOPPBB), released on 2019-11-21.
+This document describes version 0.091 of Business::ID::NOPPBB (from Perl distribution Business-ID-NOPPBB), released on 2023-10-04.
 
 =head1 SYNOPSIS
 
@@ -149,7 +150,7 @@ This module has L<Rinci> metadata.
 
 Usage:
 
- validate_nop_pbb(%args) -> [status, msg, payload, meta]
+ validate_nop_pbb(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Validate (and parse) Indonesian property tax number (NOP PBB).
 
@@ -184,16 +185,17 @@ Arguments ('*' denotes required arguments):
 
 The input string containing number to check.
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (hash)
 
@@ -205,6 +207,41 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 Source repository is at L<https://github.com/perlancar/perl-Business-ID-NOPPBB>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2019, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-NOPPBB>
@@ -213,15 +250,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
